package sun.security.krb5.internal.util;

import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteOrder;
import java.io.BufferedInputStream;

public class KrbDataInputStream extends BufferedInputStream
{
    private boolean bigEndian;
    
    public void setNativeByteOrder() {
        if (ByteOrder.nativeOrder().equals(ByteOrder.BIG_ENDIAN)) {
            this.bigEndian = true;
        }
        else {
            this.bigEndian = false;
        }
    }
    
    public KrbDataInputStream(InputStream in) {
        super(in);
        this.bigEndian = true;
    }
    
    public final int readLength4() throws IOException {
        int read = this.read(4);
        if (read < 0) {
            throw new IOException("Invalid encoding");
        }
        return read;
    }
    
    public int read(int len) throws IOException {
        byte[] b = new byte[len];
        if (super.read(b, 0, len) != len) {
            throw new IOException("Premature end of stream reached");
        }
        int n = 0;
        for (int i = 0; i < len; ++i) {
            if (this.bigEndian) {
                n |= (b[i] & 0xFF) << (len - i - 1) * 8;
            }
            else {
                n |= (b[i] & 0xFF) << i * 8;
            }
        }
        return n;
    }
    
    public int readVersion() throws IOException {
        return (super.read() & 0xFF) << 8 | (super.read() & 0xFF);
    }
}
